############
Installation
############

Requirements
############

* CPython 2.7
* `virtualenv <https://virtualenv.pypa.io/en/stable/>`_
  (only the latest 2 versions are officially supported and tested)

.. note::

    As Python 2.7 is no longer being maintained,
    terrarium's support for 2.7
    is officially deprecated
    and will be removed in a future version.

Install using pip
#################

.. code-block:: shell-session

    $ pip install terrarium

Upgrade using pip
#################

.. code-block:: shell-session

    $ pip install -U terrarium

